<?php

/**
 * @file
 * Export / edit UI plugin for grids.
 */

$plugin = array(
  'schema' => 'gridbuilder',
  'access' => 'administer gridbuilder',

  // Define the menu item.
  'menu' => array(
    // This menu item is modified in layout_menu_alter() to be a local task
    // under the regular panels layout UI.
    'menu prefix' => 'admin/structure/panels/layouts',
    'menu item' => 'grids',
    'menu title' => 'Grids',
  ),

  // Define user interface texts.
  'title singular' => t('grid'),
  'title singular proper' => t('Grid'),
  'title plural' => t('grids'),
  'title plural proper' => t('Grids'),

  'form' => array(
    'settings' => 'gridbuilder_grid_edit_form',
    'validate' => 'gridbuilder_grid_edit_form_validate',
  ),
);

/**
 * Grid item settings form.
 *
 * @see gridbuilder_grid_edit_form_validate().
 */
function gridbuilder_grid_edit_form(&$form, $form_state) {
  $grid = $form_state['item'];

  // Common form elements are already provided by ctools for admin_title
  // (human readable label) and name (machine name).

  // Master grid configuration.
  $form['grid_type'] = array(
    '#type' => 'radios',
    '#title' => t('Type of grid'),
    '#options' => array(GRIDBUILDER_FIXED => t('Fixed'), GRIDBUILDER_FLUID => t('Fluid')),
    '#description' => t('Whether the grid is fixed to a certain pixel width or fluid with percentage sizes.'),
    '#default_value' => @$grid->grid_type,
  );
  $form['width'] = array(
    '#type' => 'textfield',
    '#title' => t('Grid width'),
    '#description' => t('Enter 100% if using fluid widths, or pixel size (eg. 960px) when using fixed grids.'),
    '#default_value' => @$grid->width,
    '#states' => array(
      'visible' => array('input[name="grid_type"]' => array('value' => GRIDBUILDER_FIXED)),
    ),
  );

  // Grid detail configuration.
  $form['columns'] = array(
    '#type' => 'textfield',
    '#title' => t('Number of columns'),
    '#description' => t('Number of columns to be made available in this grid.'),
    '#default_value' => @$grid->columns,
  );
  $form['padding_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Column padding'),
    '#description' => t('Column padding in pixels or percentages. For example: 10px, 1.5%.'),
    '#default_value' => @$grid->padding_width,
  );
  $form['gutter_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Gutter width'),
    '#description' => t('Gutter width in pixels or percentages. For example: 20px, 2%.'),
    '#default_value' => @$grid->gutter_width,
  );
}

/**
 * Validation for grid item settings form.
 *
 * @see gridbuilder_grid_edit_form().
 */
function gridbuilder_grid_edit_form_validate(&$form, $form_state) {
  if (!preg_match('!^\d+$!', $form_state['values']['columns']) && $form_state['values']['columns'] != 0) {
    form_set_error('columns', t('The number of column should be a positive number.'));
  }
  if (!preg_match('!^(\d+px|[\d\.]+%)$!', $form_state['values']['padding_width'])) {
    form_set_error('padding_width', t('The column padding should be in pixels or percentages. For example: 10px or 1.5%.'));
  }
  if (!preg_match('!^(\d+px|[\d\.]+%)$!', $form_state['values']['gutter_width'])) {
    form_set_error('gutter_width', t('The gutter width should be in pixels or percentages. For example: 20px or 2%.'));
  }
}
